==> react-primitive-injector-1.1.0.tgz: package/lib/settings.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/esm/extends";
var _excluded = ["className", "style"],
    _excluded2 = ["className", "style"],
    _excluded3 = ["proviso", "combine", "children"];
import { Children, isValidElement, cloneElement } from 'react';
import { isFragment } from 'react-is';
import cx from 'classnames';
import PrimitiveInjector from './index.js';

var isUpperCaseChar = function isUpperCaseChar(_char) {
  return _char.length === 1 && _char === _char.toUpperCase();
};

var isFunction = function isFunction(handler) {
  return typeof handler === 'function';
};

var isHandler = function isHandler(propKey) {
  return propKey.startsWith('on') && isUpperCaseChar(propKey['on'.length]);
};

export var combineHandler = function combineHandler() {
  for (var _len = arguments.length, handlers = new Array(_len), _key = 0; _key < _len; _key++) {
    handlers[_key] = arguments[_key];
  }

  return function () {
    for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      args[_key2] = arguments[_key2];
    }

    return handlers.filter(isFunction).forEach(function (handler) {
      return handler.apply(void 0, args);
    });
  };
};
export var combineHandlers = function combineHandlers(ownProps, childProps, cHandler) {
  if (cHandler === void 0) {
    cHandler = combineHandler;
  }

  return Object.keys(_extends({}, ownProps, childProps)).filter(isHandler).reduce(function (response, currentKey, index, combinedKeys) {
    var _extends2;

    return _extends({}, response, (_extends2 = {}, _extends2[currentKey] = cHandler.apply(void 0, [ownProps[currentKey], childProps[currentKey]].filter(isFunction)), _extends2));
  }, {});
};
export var combineStyles = function combineStyles() {
  for (var _len3 = arguments.length, styles = new Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
    styles[_key3] = arguments[_key3];
  }

  var result = styles.reduce(function (resultingStyle, currentStyle) {
    return _extends({}, resultingStyle, currentStyle);
  }, {});
  return Object.keys(result).length === 0 ? null : result;
};
export var combineClassNames = function combineClassNames() {
  return cx.apply(void 0, arguments);
};
export var combineProps = function combineProps(_ref, _ref2, _temp) {
  var ownClassNames = _ref.className,
      _ref$style = _ref.style,
      ownStyle = _ref$style === void 0 ? {} : _ref$style,
      ownProps = _objectWithoutPropertiesLoose(_ref, _excluded);

  var childClassNames = _ref2.className,
      _ref2$style = _ref2.style,
      childStyle = _ref2$style === void 0 ? {} : _ref2$style,
      childProps = _objectWithoutPropertiesLoose(_ref2, _excluded2);

  var _ref3 = _temp === void 0 ? {
    combineHandler: combineHandler,
    combineHandlers: combineHandlers,
    combineStyles: combineStyles,
    combineClassNames: combineClassNames
  } : _temp,
      cHandlers = _ref3.combineHandlers,
      cStyles = _ref3.combineStyles,
      cClassNames = _ref3.combineClassNames,
      cHandler = _ref3.combineHandler;

  var combinedHandlers = cHandlers(ownProps, childProps, cHandler);
  var style = cStyles(ownStyle, childStyle);
  var className = cClassNames(childClassNames, ownClassNames);
  return _extends({}, className && {
    className: className
  }, style && {
    style: style
  }, ownProps, childProps, combinedHandlers);
};
export var inject = function inject(children, settings) {
  if (settings === void 0) {
    settings = [];
  }

  return Children.toArray(children).map(function (child) {
    if (! /*#__PURE__*/isValidElement(child)) {
      return child;
    } else if (isFragment(child)) {
      return /*#__PURE__*/cloneElement(child, child == null ? void 0 : child.props, inject(child == null ? void 0 : child.props.children, settings));
    } else if ((child == null ? void 0 : child.type) === PrimitiveInjector) {
      var _ref4 = (child == null ? void 0 : child.props) || {},
          _ref4$proviso = _ref4.proviso,
          proviso = _ref4$proviso === void 0 ? function () {
        return true;
      } : _ref4$proviso,
          _ref4$combine = _ref4.combine,
          combine = _ref4$combine === void 0 ? combineProps : _ref4$combine,
          _children = _ref4.children,
          otherProps = _objectWithoutPropertiesLoose(_ref4, _excluded3);

      return inject(_children, [{
        proviso: proviso,
        combine: combine,
        props: otherProps
      }].concat(settings));
    } else {
      return /*#__PURE__*/cloneElement(child, settings.filter(function (_ref5) {
        var proviso = _ref5.proviso;
        return proviso(child);
      }).reduce(function (acc, _ref6) {
        var props = _ref6.props,
            combine = _ref6.combine;
        return combine(props, acc, {
          combineHandler: combineHandler,
          combineHandlers: combineHandlers,
          combineStyles: combineStyles,
          combineClassNames: combineClassNames
        });
      }, child == null ? void 0 : child.props));
    }
  });
};

==> react-primitive-injector-1.2.0.tgz: package/lib/settings.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/esm/extends";
var _excluded = ["className", "style"],
    _excluded2 = ["className", "style"],
    _excluded3 = ["proviso", "combine", "children"];
import { Children, cloneElement, isValidElement } from 'react';
import { isFragment } from 'react-is';
import cx from 'classnames';
import PrimitiveInjector from './index.js';

var isUpperCaseChar = function isUpperCaseChar(_char) {
  return _char.length === 1 && _char === _char.toUpperCase();
};

var isFunction = function isFunction(handler) {
  return typeof handler === 'function';
};

var isHandler = function isHandler(propKey) {
  return propKey.startsWith('on') && isUpperCaseChar(propKey['on'.length]);
};

export var combineHandler = function combineHandler() {
  for (var _len = arguments.length, handlers = new Array(_len), _key = 0; _key < _len; _key++) {
    handlers[_key] = arguments[_key];
  }

  return function () {
    for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      args[_key2] = arguments[_key2];
    }

    return handlers.filter(isFunction).forEach(function (handler) {
      return handler.apply(void 0, args);
    });
  };
};
export var combineHandlers = function combineHandlers(ownProps, childProps, cHandler) {
  if (cHandler === void 0) {
    cHandler = combineHandler;
  }

  return Object.keys(_extends({}, ownProps, childProps)).filter(isHandler).reduce(function (response, currentKey, index, combinedKeys) {
    var _extends2;

    return _extends({}, response, (_extends2 = {}, _extends2[currentKey] = cHandler.apply(void 0, [ownProps[currentKey], childProps[currentKey]].filter(isFunction)), _extends2));
  }, {});
};
export var combineStyles = function combineStyles() {
  for (var _len3 = arguments.length, styles = new Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
    styles[_key3] = arguments[_key3];
  }

  var result = styles.reduce(function (resultingStyle, currentStyle) {
    return _extends({}, resultingStyle, currentStyle);
  }, {});
  return Object.keys(result).length === 0 ? null : result;
};
export var combineClassNames = function combineClassNames() {
  return cx.apply(void 0, arguments);
};
export var combineProps = function combineProps(_ref, _ref2, _temp) {
  var ownClassNames = _ref.className,
      _ref$style = _ref.style,
      ownStyle = _ref$style === void 0 ? {} : _ref$style,
      ownProps = _objectWithoutPropertiesLoose(_ref, _excluded);

  var childClassNames = _ref2.className,
      _ref2$style = _ref2.style,
      childStyle = _ref2$style === void 0 ? {} : _ref2$style,
      childProps = _objectWithoutPropertiesLoose(_ref2, _excluded2);

  var _ref3 = _temp === void 0 ? {
    combineHandler: combineHandler,
    combineHandlers: combineHandlers,
    combineStyles: combineStyles,
    combineClassNames: combineClassNames
  } : _temp,
      cHandlers = _ref3.combineHandlers,
      cStyles = _ref3.combineStyles,
      cClassNames = _ref3.combineClassNames,
      cHandler = _ref3.combineHandler;

  var combinedHandlers = cHandlers(ownProps, childProps, cHandler);
  var style = cStyles(ownStyle, childStyle);
  var className = cClassNames(childClassNames, ownClassNames);
  return _extends({}, className && {
    className: className
  }, style && {
    style: style
  }, ownProps, childProps, combinedHandlers);
};
export var inject = function inject(children, settings) {
  if (settings === void 0) {
    settings = [];
  }

  return Children.toArray(children).map(function (child) {
    if (! /*#__PURE__*/isValidElement(child)) {
      return child;
    } else if (isFragment(child)) {
      return /*#__PURE__*/cloneElement(child, child == null ? void 0 : child.props, inject(child == null ? void 0 : child.props.children, settings));
    } else if ((child == null ? void 0 : child.type) === PrimitiveInjector) {
      var _ref4 = (child == null ? void 0 : child.props) || {},
          _ref4$proviso = _ref4.proviso,
          proviso = _ref4$proviso === void 0 ? function () {
        return true;
      } : _ref4$proviso,
          _ref4$combine = _ref4.combine,
          combine = _ref4$combine === void 0 ? combineProps : _ref4$combine,
          _children = _ref4.children,
          otherProps = _objectWithoutPropertiesLoose(_ref4, _excluded3);

      return inject(_children, [{
        proviso: proviso,
        combine: combine,
        props: otherProps
      }].concat(settings));
    } else {
      return /*#__PURE__*/cloneElement(child, settings.filter(function (_ref5) {
        var proviso = _ref5.proviso;
        return proviso(child);
      }).reduce(function (acc, _ref6) {
        var props = _ref6.props,
            combine = _ref6.combine;
        return combine(props, acc, {
          combineHandler: combineHandler,
          combineHandlers: combineHandlers,
          combineStyles: combineStyles,
          combineClassNames: combineClassNames
        });
      }, child == null ? void 0 : child.props));
    }
  });
};
